[nautilus-actions] NATimeout, na_about are renamed FMATimeout, fma_about



commit 5e50b39e261045d162d42b8a037cd6c4f168a867
Author: Pierre Wieser <pwieser trychlos org>
Date:   Mon Sep 7 23:14:23 2015 +0200

    NATimeout, na_about are renamed FMATimeout, fma_about

 src/api/Makefile.am                      |   16 +++++++-------
 src/api/fma-iio-provider.h               |    2 +-
 src/api/{na-timeout.h => fma-timeout.h}  |   34 +++++++++++++++---------------
 src/core/Makefile.am                     |    6 ++--
 src/core/{na-about.c => fma-about.c}     |   22 +++++++++---------
 src/core/{na-about.h => fma-about.h}     |   16 +++++++-------
 src/core/fma-core-utils.c                |    4 +-
 src/core/{na-timeout.c => fma-timeout.c} |   10 ++++----
 src/core/na-pivot.c                      |    6 ++--
 src/core/na-settings.c                   |    6 ++--
 src/io-desktop/nadp-desktop-provider.c   |    2 +-
 src/io-desktop/nadp-desktop-provider.h   |    4 +-
 src/nact/nact-application.c              |    4 +-
 src/nact/nact-main-window.c              |   10 ++++----
 src/nact/nact-menu-file.c                |    6 ++--
 src/nact/nact-menu.c                     |    4 +-
 src/plugin-menu/nautilus-actions.c       |   14 ++++++------
 17 files changed, 83 insertions(+), 83 deletions(-)
---
diff --git a/src/api/Makefile.am b/src/api/Makefile.am
index 5967e7c..50a30b6 100644
--- a/src/api/Makefile.am
+++ b/src/api/Makefile.am
@@ -34,26 +34,26 @@ api_include_HEADERS = \
        fma-iexporter.h                                                                         \
        fma-iimporter.h                                                                         \
        fma-ifactory-provider.h                                                         \
-       fma-ifactory-provider-provider.h                                                \
+       fma-ifactory-provider-provider.h                                        \
        fma-iio-provider.h                                                                      \
        \
        fma-boxed.h                                                                                     \
-       fma-core-utils.h                                                                                \
-       fma-data-boxed.h                                                                                \
+       fma-core-utils.h                                                                        \
+       fma-data-boxed.h                                                                        \
        fma-data-def.h                                                                          \
-       fma-data-types.h                                                                                \
+       fma-data-types.h                                                                        \
        fma-gconf-monitor.h                                                                     \
        fma-gconf-utils.h                                                                       \
        fma-icontext.h                                                                          \
        fma-iduplicable.h                                                                       \
        fma-ifactory-object.h                                                           \
        fma-ifactory-object-data.h                                                      \
-       fma-object-api.h                                                                                \
-       fma-object.h                                                                                    \
+       fma-object-api.h                                                                        \
+       fma-object.h                                                                            \
        fma-object-id.h                                                                         \
        fma-object-item.h                                                                       \
        fma-object-action.h                                                                     \
-       fma-object-profile.h                                                                    \
+       fma-object-profile.h                                                            \
        fma-object-menu.h                                                                       \
-       na-timeout.h                                                                            \
+       fma-timeout.h                                                                           \
        $(NULL)
diff --git a/src/api/fma-iio-provider.h b/src/api/fma-iio-provider.h
index aee7f71..1ab2b84 100644
--- a/src/api/fma-iio-provider.h
+++ b/src/api/fma-iio-provider.h
@@ -90,7 +90,7 @@
  *   </para>
  *   <para>
  *    The #FMAIIOProvider interface does not define specific monitoring
- *    methods (but you can also take a glance at #NATimeout object).
+ *    methods (but you can also take a glance at #FMATimeout object).
  *    Instead, it is waited that the I/O provider module takes care
  *    itself of managing its own monitoring services at
  *    load/unload time, calling the fma_iio_provider_item_changed()
diff --git a/src/core/Makefile.am b/src/core/Makefile.am
index 6161e17..e40d34d 100644
--- a/src/core/Makefile.am
+++ b/src/core/Makefile.am
@@ -51,8 +51,8 @@ AM_CPPFLAGS += \
        $(NULL)
 
 libna_core_la_SOURCES = \
-       na-about.c                                                                                      \
-       na-about.h                                                                                      \
+       fma-about.c                                                                                     \
+       fma-about.h                                                                                     \
        fma-boxed.c                                                                                     \
        fma-core-utils.c                                                                                \
        fma-data-boxed.c                                                                                \
@@ -117,7 +117,7 @@ libna_core_la_SOURCES = \
        na-selected-info.h                                                                      \
        na-settings.c                                                                           \
        na-settings.h                                                                           \
-       na-timeout.c                                                                            \
+       fma-timeout.c                                                                           \
        na-tokens.c                                                                                     \
        na-tokens.h                                                                                     \
        na-updater.c                                                                            \
diff --git a/src/core/na-about.c b/src/core/fma-about.c
similarity index 92%
rename from src/core/na-about.c
rename to src/core/fma-about.c
index 0786386..5cd7d10 100644
--- a/src/core/na-about.c
+++ b/src/core/fma-about.c
@@ -34,18 +34,18 @@
 #include <glib/gi18n.h>
 #include <libintl.h>
 
-#include "na-about.h"
+#include "fma-about.h"
 
 static const gchar *st_icon_filename    = ICON_FNAME;
 
 /*
- * na_about_display:
+ * fma_about_display:
  * @toplevel: the parent window.
  *
  * Displays the About dialog.
  */
 void
-na_about_display( GtkWindow *toplevel )
+fma_about_display( GtkWindow *toplevel )
 {
        gchar *application_name, *copyright;
        int i;
@@ -84,8 +84,8 @@ na_about_display( GtkWindow *toplevel )
                NULL
        };
 
-       application_name = na_about_get_application_name();
-       copyright = na_about_get_copyright( FALSE );
+       application_name = fma_about_get_application_name();
+       copyright = fma_about_get_copyright( FALSE );
 
        i = 0;
        license_i18n = g_string_new( "" );
@@ -120,20 +120,20 @@ na_about_display( GtkWindow *toplevel )
 }
 
 /*
- * na_about_get_application_name:
+ * fma_about_get_application_name:
  *
  * Returns: the name of the application, as a newly allocated string
  * which should be g_free() by the caller.
  */
 gchar *
-na_about_get_application_name( void )
+fma_about_get_application_name( void )
 {
        /* i18n: title of the About dialog box, when seen from Nautilus file manager */
        return( g_strdup( _( "FileManager-Actions" )));
 }
 
 /*
- * na_about_get_icon_name:
+ * fma_about_get_icon_name:
  *
  * Returns: the name of the default icon for the application.
  *
@@ -143,20 +143,20 @@ na_about_get_application_name( void )
  * while st_icon_filename points to full path of the icon.
  */
 const gchar *
-na_about_get_icon_name( void )
+fma_about_get_icon_name( void )
 {
        return( st_icon_filename );
 }
 
 /*
- * na_about_get_copyright:
+ * fma_about_get_copyright:
  * @console: whether the string is to be printed on a console.
  *
  * Returns: the copyright string, as a newly allocated string which
  * should be g_free() by the caller.
  */
 gchar *
-na_about_get_copyright( gboolean console )
+fma_about_get_copyright( gboolean console )
 {
        gchar *copyright;
        gchar *symbol;
diff --git a/src/core/na-about.h b/src/core/fma-about.h
similarity index 80%
rename from src/core/na-about.h
rename to src/core/fma-about.h
index 95c0543..572deaf 100644
--- a/src/core/na-about.h
+++ b/src/core/fma-about.h
@@ -27,12 +27,12 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __CORE_NA_ABOUT_H__
-#define __CORE_NA_ABOUT_H__
+#ifndef __CORE_FMA_ABOUT_H__
+#define __CORE_FMA_ABOUT_H__
 
 /* @title NAAbout
  * @short_description: The #NAAbout API
- * @include: runtime/na-about.h
+ * @include: runtime/fma-about.h
  *
  * These functions displays the 'About FileManager-Actions' dialog box,
  * and provides contant informations about the application.
@@ -42,12 +42,12 @@
 
 G_BEGIN_DECLS
 
-void         na_about_display( GtkWindow *parent );
+void         fma_about_display( GtkWindow *parent );
 
-gchar       *na_about_get_application_name( void );
-const gchar *na_about_get_icon_name( void );
-gchar       *na_about_get_copyright( gboolean console );
+gchar       *fma_about_get_application_name( void );
+const gchar *fma_about_get_icon_name( void );
+gchar       *fma_about_get_copyright( gboolean console );
 
 G_END_DECLS
 
-#endif /* __CORE_NA_IABOUT_H__ */
+#endif /* __CORE_FMA_IABOUT_H__ */
diff --git a/src/core/fma-core-utils.c b/src/core/fma-core-utils.c
index 3086168..b2051f4 100644
--- a/src/core/fma-core-utils.c
+++ b/src/core/fma-core-utils.c
@@ -40,7 +40,7 @@
 
 #include <api/fma-core-utils.h>
 
-#include "na-about.h"
+#include "fma-about.h"
 
 /* minimal and maximal size for loading the content of a file in memory
  * used by fma_core_utils_file_is_size_ok()
@@ -1223,7 +1223,7 @@ fma_core_utils_print_version( void )
 
        g_print( "\n" );
        g_print( "%s (%s) v %s\n", g_get_prgname(), PACKAGE_NAME, PACKAGE_VERSION );
-       copyright = na_about_get_copyright( TRUE );
+       copyright = fma_about_get_copyright( TRUE );
        g_print( "%s\n", copyright );
        g_free( copyright );
 
diff --git a/src/core/na-pivot.c b/src/core/na-pivot.c
index 799bdeb..0ce7e26 100644
--- a/src/core/na-pivot.c
+++ b/src/core/na-pivot.c
@@ -34,7 +34,7 @@
 #include <string.h>
 
 #include <api/fma-core-utils.h>
-#include <api/na-timeout.h>
+#include <api/fma-timeout.h>
 
 #include "na-io-provider.h"
 #include "na-module.h"
@@ -63,7 +63,7 @@ struct _NAPivotPrivate {
 
        /* timeout to manage i/o providers 'item-changed' burst
         */
-       NATimeout   change_timeout;
+       FMATimeout   change_timeout;
 };
 
 /* NAPivot properties
@@ -217,7 +217,7 @@ instance_init( GTypeInstance *instance, gpointer klass )
        /* initialize timeout parameters for 'item-changed' handler
         */
        self->private->change_timeout.timeout = st_burst_timeout;
-       self->private->change_timeout.handler = ( NATimeoutFunc ) on_items_changed_timeout;
+       self->private->change_timeout.handler = ( FMATimeoutFunc ) on_items_changed_timeout;
        self->private->change_timeout.user_data = self;
        self->private->change_timeout.source_id = 0;
 }
diff --git a/src/core/na-settings.c b/src/core/na-settings.c
index 0508130..6d8cbaf 100644
--- a/src/core/na-settings.c
+++ b/src/core/na-settings.c
@@ -39,7 +39,7 @@
 #include "api/fma-boxed.h"
 #include "api/fma-data-types.h"
 #include "api/fma-core-utils.h"
-#include "api/na-timeout.h"
+#include "api/fma-timeout.h"
 
 #include "na-settings.h"
 
@@ -114,7 +114,7 @@ struct _NASettingsPrivate {
        KeyFile  *user;
        GList    *content;
        GList    *consumers;
-       NATimeout timeout;
+       FMATimeout timeout;
 };
 
 #define GROUP_NACT                                             "nact"
@@ -345,7 +345,7 @@ instance_init( GTypeInstance *instance, gpointer klass )
        self->private->consumers = NULL;
 
        self->private->timeout.timeout = st_burst_timeout;
-       self->private->timeout.handler = ( NATimeoutFunc ) on_keyfile_changed_timeout;
+       self->private->timeout.handler = ( FMATimeoutFunc ) on_keyfile_changed_timeout;
        self->private->timeout.user_data = NULL;
        self->private->timeout.source_id = 0;
 }
diff --git a/src/io-desktop/nadp-desktop-provider.c b/src/io-desktop/nadp-desktop-provider.c
index 5e2072f..03ca3a7 100644
--- a/src/io-desktop/nadp-desktop-provider.c
+++ b/src/io-desktop/nadp-desktop-provider.c
@@ -173,7 +173,7 @@ instance_init( GTypeInstance *instance, gpointer klass )
        self->private->dispose_has_run = FALSE;
        self->private->monitors = NULL;
        self->private->timeout.timeout = st_burst_timeout;
-       self->private->timeout.handler = ( NATimeoutFunc ) on_monitor_timeout;
+       self->private->timeout.handler = ( FMATimeoutFunc ) on_monitor_timeout;
        self->private->timeout.user_data = self;
        self->private->timeout.source_id = 0;
 }
diff --git a/src/io-desktop/nadp-desktop-provider.h b/src/io-desktop/nadp-desktop-provider.h
index 9f70786..448f381 100644
--- a/src/io-desktop/nadp-desktop-provider.h
+++ b/src/io-desktop/nadp-desktop-provider.h
@@ -41,7 +41,7 @@
  */
 
 #include <api/fma-object-item.h>
-#include <api/na-timeout.h>
+#include <api/fma-timeout.h>
 
 #include "nadp-desktop-file.h"
 
@@ -60,7 +60,7 @@ typedef struct _NadpDesktopProviderPrivate {
        /*< private >*/
        gboolean  dispose_has_run;
        GList    *monitors;
-       NATimeout timeout;
+       FMATimeout timeout;
 }
        NadpDesktopProviderPrivate;
 
diff --git a/src/nact/nact-application.c b/src/nact/nact-application.c
index e3a2ca4..36115ff 100644
--- a/src/nact/nact-application.c
+++ b/src/nact/nact-application.c
@@ -36,7 +36,7 @@
 
 #include "api/fma-core-utils.h"
 
-#include "core/na-about.h"
+#include "core/fma-about.h"
 
 #include "base-isession.h"
 #include "nact-application.h"
@@ -229,7 +229,7 @@ nact_application_new( void )
        priv = application->private;
        priv->application_name = gettext( st_application_name );
        priv->description = gettext( st_description );
-       priv->icon_name = na_about_get_icon_name();
+       priv->icon_name = fma_about_get_icon_name();
 
        return( application );
 }
diff --git a/src/nact/nact-main-window.c b/src/nact/nact-main-window.c
index d54e181..1d98aa9 100644
--- a/src/nact/nact-main-window.c
+++ b/src/nact/nact-main-window.c
@@ -35,9 +35,9 @@
 #include <stdlib.h>
 
 #include "api/fma-object-api.h"
-#include "api/na-timeout.h"
+#include "api/fma-timeout.h"
 
-#include "core/na-about.h"
+#include "core/fma-about.h"
 #include "core/na-gtk-utils.h"
 #include "core/na-iprefs.h"
 #include "core/na-pivot.h"
@@ -119,7 +119,7 @@ struct _NactMainWindowPrivate {
        NactSortButtons *sort_buttons;
 
        gulong           pivot_handler_id;
-       NATimeout        pivot_timeout;
+       FMATimeout        pivot_timeout;
 };
 
 /* properties set against the main window
@@ -513,7 +513,7 @@ instance_init( GTypeInstance *instance, gpointer klass )
        /* initialize timeout parameters when blocking 'pivot-items-changed' handler
         */
        priv->pivot_timeout.timeout = st_burst_timeout;
-       priv->pivot_timeout.handler = ( NATimeoutFunc ) on_block_items_changed_timeout;
+       priv->pivot_timeout.handler = ( FMATimeoutFunc ) on_block_items_changed_timeout;
        priv->pivot_timeout.user_data = self;
        priv->pivot_timeout.source_id = 0;
 }
@@ -754,7 +754,7 @@ setup_main_ui( NactMainWindow *main_window )
 
        /* application icon
         */
-       gtk_window_set_default_icon_from_file( na_about_get_icon_name(), NULL );
+       gtk_window_set_default_icon_from_file( fma_about_get_icon_name(), NULL );
 }
 
 /*
diff --git a/src/nact/nact-menu-file.c b/src/nact/nact-menu-file.c
index 03c6ac5..3bb6903 100644
--- a/src/nact/nact-menu-file.c
+++ b/src/nact/nact-menu-file.c
@@ -35,7 +35,7 @@
 #include <libintl.h>
 
 #include <api/fma-core-utils.h>
-#include <api/na-timeout.h>
+#include <api/fma-timeout.h>
 
 #include <core/na-io-provider.h>
 #include <core/na-iprefs.h>
@@ -48,7 +48,7 @@
 #include "nact-menu-file.h"
 #include "nact-tree-ieditable.h"
 
-static NATimeout st_autosave_prefs_timeout = { 0 };
+static FMATimeout st_autosave_prefs_timeout = { 0 };
 static guint     st_event_autosave         = 0;
 
 static gchar *st_save_error       = N_( "Save error" );
@@ -380,7 +380,7 @@ static void
 install_autosave( NactMainWindow *main_window )
 {
        st_autosave_prefs_timeout.timeout = 100;
-       st_autosave_prefs_timeout.handler = ( NATimeoutFunc ) on_autosave_prefs_timeout;
+       st_autosave_prefs_timeout.handler = ( FMATimeoutFunc ) on_autosave_prefs_timeout;
        st_autosave_prefs_timeout.user_data = main_window;
 
        na_settings_register_key_callback( NA_IPREFS_MAIN_SAVE_AUTO, G_CALLBACK( on_autosave_prefs_changed ), 
NULL );
diff --git a/src/nact/nact-menu.c b/src/nact/nact-menu.c
index 44420f9..21be110 100644
--- a/src/nact/nact-menu.c
+++ b/src/nact/nact-menu.c
@@ -33,7 +33,7 @@
 
 #include <glib/gi18n.h>
 
-#include "core/na-about.h"
+#include "core/fma-about.h"
 #include "core/na-io-provider.h"
 
 #include "nact-main-window.h"
@@ -251,7 +251,7 @@ on_app_about( GSimpleAction *action, GVariant *parameter, gpointer user_data )
        window = gtk_application_get_active_window( GTK_APPLICATION( user_data ));
        g_return_if_fail( window && NACT_IS_MAIN_WINDOW( window ));
 
-       na_about_display( window );
+       fma_about_display( window );
 }
 
 static void
diff --git a/src/plugin-menu/nautilus-actions.c b/src/plugin-menu/nautilus-actions.c
index 6a5fe8c..d65344d 100644
--- a/src/plugin-menu/nautilus-actions.c
+++ b/src/plugin-menu/nautilus-actions.c
@@ -41,10 +41,10 @@
 
 #include <api/fma-core-utils.h>
 #include <api/fma-object-api.h>
-#include <api/na-timeout.h>
+#include <api/fma-timeout.h>
 
 #include <core/na-pivot.h>
-#include <core/na-about.h>
+#include <core/fma-about.h>
 #include <core/na-selected-info.h>
 #include <core/na-tokens.h>
 
@@ -63,7 +63,7 @@ struct _NautilusActionsPrivate {
        NAPivot  *pivot;
        gulong    items_changed_handler;
        gulong    settings_changed_handler;
-       NATimeout change_timeout;
+       FMATimeout change_timeout;
 };
 
 static GObjectClass *st_parent_class  = NULL;
@@ -180,7 +180,7 @@ instance_init( GTypeInstance *instance, gpointer klass )
 
        self->private->dispose_has_run = FALSE;
        self->private->change_timeout.timeout = st_burst_timeout;
-       self->private->change_timeout.handler = ( NATimeoutFunc ) on_change_event_timeout;
+       self->private->change_timeout.handler = ( FMATimeoutFunc ) on_change_event_timeout;
        self->private->change_timeout.user_data = self;
        self->private->change_timeout.source_id = 0;
 }
@@ -935,7 +935,7 @@ create_root_menu( NautilusActions *plugin, GList *menu )
                        _( "FileManager-Actions actions" ),
                        /* i18n: tooltip of an automagic root submenu */
                        _( "A submenu which embeds the currently available FileManager-Actions actions and 
menus" ),
-                       na_about_get_icon_name());
+                       fma_about_get_icon_name());
        attach_submenu_to_item( root_item, menu );
        nautilus_menu = g_list_append( NULL, root_item );
 
@@ -980,7 +980,7 @@ add_about_item( NautilusActions *plugin, GList *menu )
                                "AboutNautilusActions",
                                _( "About FileManager-Actions" ),
                                _( "Display some information about FileManager-Actions" ),
-                               na_about_get_icon_name());
+                               fma_about_get_icon_name());
 
                g_signal_connect_data(
                                about_item,
@@ -1001,7 +1001,7 @@ execute_about( NautilusMenuItem *item, NautilusActions *plugin )
 {
        g_return_if_fail( NAUTILUS_IS_ACTIONS( plugin ));
 
-       na_about_display( NULL );
+       fma_about_display( NULL );
 }
 
 /*


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/api/na-timeout.h b/src/api/fma-timeout.h
similarity index 79%
rename from src/api/na-timeout.h
rename to src/api/fma-timeout.h
index 58f94cd..36bc6fa 100644
--- a/src/api/na-timeout.h
+++ b/src/api/fma-timeout.h
@@ -27,16 +27,16 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __FILE_MANAGER_ACTIONS_API_NA_TIMEOUT_H__
-#define __FILE_MANAGER_ACTIONS_API_NA_TIMEOUT_H__
+#ifndef __FILE_MANAGER_ACTIONS_API_TIMEOUT_H__
+#define __FILE_MANAGER_ACTIONS_API_TIMEOUT_H__
 
 /**
  * SECTION: timeout
  * @title: NATimeout
  * @short_description: The NATimeout Structure
  * @include: file-manager-actions/na-timeout.h
  *
  * The NATimeout structure is a convenience structure to manage timeout
  * functions.
  *
  * Since: 3.1
@@ -47,17 +47,17 @@
 G_BEGIN_DECLS
 
 /**
- * NATimeoutFunc:
+ * FMATimeoutFunc:
  * @user_data: data to be passed to the callback function.
  *
  * Prototype of the callback function.
  *
  * Since: 3.1
  */
-typedef void ( *NATimeoutFunc )( void *user_data );
+typedef void ( *FMATimeoutFunc )( void *user_data );
 
 /**
- * NATimeout:
+ * FMATimeout:
  * @timeout:   (i) timeout configurable parameter (ms)
  * @handler:   (i) handler function
  * @user_data: (i) user data
@@ -81,17 +81,17 @@ typedef void ( *NATimeoutFunc )( void *user_data );
  */
 typedef struct {
        /*< public >*/
-       guint         timeout;
-       NATimeoutFunc handler;
-       gpointer      user_data;
+       guint          timeout;
+       FMATimeoutFunc handler;
+       gpointer       user_data;
        /*< private >*/
-       GTimeVal      last_time;
-       guint         source_id;
+       GTimeVal       last_time;
+       guint          source_id;
 }
-       NATimeout;
+       FMATimeout;
 
-void na_timeout_event( NATimeout *timeout );
+void na_timeout_event( FMATimeout *timeout );
 
 G_END_DECLS
 
-#endif /* __FILE_MANAGER_ACTIONS_API_NA_TIMEOUT_H__ */
+#endif /* __FILE_MANAGER_ACTIONS_API_TIMEOUT_H__ */
@@ -27,16 +27,16 @@
 /**
  * SECTION: timeout
- * @title: NATimeout
- * @short_description: The NATimeout Structure
- * @include: file-manager-actions/na-timeout.h
+ * @title: FMATimeout
+ * @short_description: The FMATimeout Structure
+ * @include: file-manager-actions/fma-timeout.h
  *
@@ -27,16 +27,16 @@
  *
- * The NATimeout structure is a convenience structure to manage timeout
+ * The FMATimeout structure is a convenience structure to manage timeout
  * functions.
  *
diff --git a/src/core/na-timeout.c b/src/core/fma-timeout.c
similarity index 91%
rename from src/core/na-timeout.c
rename to src/core/fma-timeout.c
index ed038ba..33ff528 100644
--- a/src/core/na-timeout.c
+++ b/src/core/fma-timeout.c
@@ -31,17 +31,17 @@
 #include <config.h>
 #endif
 
-#include <api/na-timeout.h>
+#include <api/fma-timeout.h>
 
-static gboolean on_timeout_event_timeout( NATimeout *timeout );
+static gboolean on_timeout_event_timeout( FMATimeout *timeout );
 static gulong   time_val_diff( const GTimeVal *recent, const GTimeVal *old );
 
 /**
  * na_timeout_event:
  * @timeout: the #NATimeout structure which will handle this event.
  */
 void
-na_timeout_event( NATimeout *event )
+na_timeout_event( FMATimeout *event )
 {
        g_return_if_fail( event != NULL );
 
@@ -57,7 +57,7 @@ na_timeout_event( NATimeout *event )
  * we continue to loop until last event is older that our burst timeout
  */
 static gboolean
-on_timeout_event_timeout( NATimeout *timeout )
+on_timeout_event_timeout( FMATimeout *timeout )
 {
        GTimeVal now;
        gulong diff;
@@ -31,17 +31,17 @@
 /**
  * na_timeout_event:
- * @timeout: the #NATimeout structure which will handle this event.
+ * @timeout: the #FMATimeout structure which will handle this event.
  */
 void